# earthkit.maps

![earthkit-maps](docs/_static/earthkit-maps.png)

[![PyPI version fury.io](https://badge.fury.io/py/earthkit-maps.svg)](https://pypi.python.org/pypi/earthkit-maps/)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/earthkit-maps.svg)](https://pypi.python.org/pypi/earthkit-maps/)

**DISCLAIMER**

> This project is in the **BETA** stage of development. Please be aware that interfaces and functionality may change as the project develops. If this software is to be used in operational systems you are **strongly advised to use a released tag in your system configuration**, and you should be willing to accept incoming changes and bug fixes that require adaptations on your part. ECMWF **does use** this software in operations and abides by the same caveats.

Format-agnostics geospatial visualisation tools and templates.

## Documentation

The documentation can be found at https://earthkit-maps.readthedocs.io/.

## Install

Install via `pip` with:

```
$ pip install earthkit-maps
```

More details, such optional additional dependencies, can be found  at
https://earthkit-data.readthedocs.io/en/latest/install.html.

## License

```
Copyright 2023, European Centre for Medium Range Weather Forecasts.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
```
